.. _github-stats-3_10_5:

GitHub statistics for 3.10.5 (Jul 31, 2025)
===========================================

GitHub statistics for 2024/12/14 (tag: v3.10.0) - 2025/07/31

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 18 issues and merged 67 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/102?closed=1>`__

The following 36 authors contributed 371 commits.

* Antony Lee
* Brian Christian
* chrisjbillington
* Christine P. Chai
* Clément Robert
* David Stansby
* dependabot[bot]
* Elliott Sales de Andrade
* G.D. McBain
* Greg Lucas
* hannah
* hu-xiaonan
* Ian Thomas
* ianlv
* IdiotCoffee
* Ines Cachola
* Inês Cachola
* Jody Klymak
* Jouni K. Seppänen
* Khushi_29
* Kyle Sunden
* Lumberbot (aka Jack)
* N R Navaneet
* Nathan G. Wiseman
* Oscar Gustafsson
* Praful Gulani
* Qian Zhang
* Raphael Erik Hviding
* Roman
* Roman A
* Ruth Comer
* saikarna913
* Scott Shambaugh
* Thomas A Caswell
* Tim Hoffmann
* Trygve Magnus Ræder

GitHub issues and pull requests:

Pull Requests (67):

* :ghpull:`30357`: CIBW updates: fix pypy sections, update cibw version
* :ghpull:`30356`: Manual Backport PR #30195 on branch v3.10.x (ci: Enable wheel builds on Python 3.14)
* :ghpull:`30352`: Backport PR #28554 on branch v3.10.x (BLD: Enable wheels on Windows-on-ARM)
* :ghpull:`30353`: Backport PR #30345 on branch v3.10.x (qt: Use better devicePixelRatio event to refresh scaling)
* :ghpull:`30350`: Backport PR #30344 on branch v3.10.x (Support fractional HiDPI in GTK4 backend)
* :ghpull:`30277`: Backport PR #30271 on branch v3.10.x (Reduce pause time in interactive timer test)
* :ghpull:`30351`: Backport PR #30327 on branch v3.10.x (FIX Update Axes limits from Axes.add_collection(... autolim=True))
* :ghpull:`30345`: qt: Use better devicePixelRatio event to refresh scaling
* :ghpull:`28554`: BLD: Enable wheels on Windows-on-ARM
* :ghpull:`30292`: Backport PR #30237: Add explicit ``**options: Any`` for ``add_subplot`` m…
* :ghpull:`29935`: Backport PR #29908 on branch v3.10.x (TST: Use text placeholders for empty legends)
* :ghpull:`30327`: FIX Update Axes limits from Axes.add_collection(... autolim=True)
* :ghpull:`30344`: Support fractional HiDPI in GTK4 backend
* :ghpull:`30326`: Backport PR #30321 on branch v3.10.x (Fix type annotation for Axes.get_legend() to include None)
* :ghpull:`30321`: Fix type annotation for Axes.get_legend() to include None
* :ghpull:`30287`: Backport PR #30286 on branch v3.10.x (Fix whitespace in _axes.py error message)
* :ghpull:`30288`: Backport PR #30283 on branch v3.10.x (changed the FAQ link to point to the correct path)
* :ghpull:`30293`: Backport PR #30289 on branch v3.10.x (DOC: Fix build with pybind11 3)
* :ghpull:`30283`: changed the FAQ link to point to the correct path
* :ghpull:`30286`: Fix whitespace in _axes.py error message
* :ghpull:`30271`: Reduce pause time in interactive timer test
* :ghpull:`30269`: Backport PR #30186 on branch v3.10.x (Fix figure legend when drawing stackplots)
* :ghpull:`30186`: Fix figure legend when drawing stackplots
* :ghpull:`30268`: Backport PR #30233 on branch v3.10.x (Check that stem input is 1D)
* :ghpull:`30233`: Check that stem input is 1D
* :ghpull:`30259`: Backport PR #30256 on branch v3.10.x (Time out in _get_executable_info)
* :ghpull:`30256`: Time out in _get_executable_info
* :ghpull:`30237`: Add explicit ``**options: Any`` for ``add_subplot`` method
* :ghpull:`30253`: Backport PR #30243 on branch v3.10.x (Fix FancyArrow rendering for zero-length arrows)
* :ghpull:`30243`: Fix FancyArrow rendering for zero-length arrows
* :ghpull:`30250`: Backport PR #30244 on branch v3.10.x (DOC: Recommend to use bare Figure instances for saving to file)
* :ghpull:`30247`: Backport PR #30246 on branch v3.10.x (chore: remove redundant words in comment)
* :ghpull:`30246`: chore: remove redundant words in comment
* :ghpull:`30240`: Backport PR #30236 on branch v3.10.x (Copy-edit the docstring of AuxTransformBox.)
* :ghpull:`30236`: Copy-edit the docstring of AuxTransformBox.
* :ghpull:`30234`: Backport PR #30209 on branch v3.10.x (Clean up Qt socket notifier to avoid spurious interrupt handler calls)
* :ghpull:`30209`: Clean up Qt socket notifier to avoid spurious interrupt handler calls
* :ghpull:`30195`: ci: Enable wheel builds on Python 3.14
* :ghpull:`30229`: Backport PR #30221 on branch v3.10.x (BUG: fix future incompatibility with Pillow 13)
* :ghpull:`30221`: BUG: fix future incompatibility with Pillow 13
* :ghpull:`30228`: Backport PR #30098 on branch v3.10.x (Fix label_outer in the presence of colorbars.)
* :ghpull:`30227`: Backport PR #30223 on branch v3.10.x (Polar log scale: fix inner patch boundary and spine location)
* :ghpull:`30098`: Fix label_outer in the presence of colorbars.
* :ghpull:`30223`: Polar log scale: fix inner patch boundary and spine location
* :ghpull:`30217`: Backport PR #30198 on branch v3.10.x (Implement Path.__deepcopy__ avoiding infinite recursion)
* :ghpull:`30198`: Implement Path.__deepcopy__ avoiding infinite recursion
* :ghpull:`30213`: Backport PR #30212 on branch v3.10.x ([Doc]: fix bug in release notes for matplotlib v3.5.0 and v3.7.0)
* :ghpull:`30189`: Backport PR #30180 on branch v3.10.x (DOC: expand polar example)
* :ghpull:`30167`: Backport PR #30162 on branch v3.10.x (TST: Fix runtime error checking NaN input to format_cursor_data)
* :ghpull:`30162`: TST: Fix runtime error checking NaN input to format_cursor_data
* :ghpull:`30146`: Backport PR #30144 on branch v3.10.x (js: Fix externally-controlled format strings)
* :ghpull:`30144`: js: Fix externally-controlled format strings
* :ghpull:`30140`: Backport PR #30118 on branch v3.10.x (CI: Skip jobs on forks)
* :ghpull:`30120`: Backport PR #30114 on branch v3.10.x (Fix _is_tensorflow_array.)
* :ghpull:`30122`: Backport PR #30119 on branch v3.10.x (Add some types to _mathtext.py)
* :ghpull:`30119`: Add some types to _mathtext.py
* :ghpull:`30114`: Fix _is_tensorflow_array.
* :ghpull:`30106`: Backport PR #30089 on branch v3.10.x (FIX: fix submerged margins algorithm being applied twice)
* :ghpull:`30089`: FIX: fix submerged margins algorithm being applied twice
* :ghpull:`30101`: Backport PR #30096 on branch v3.10.x (Fix OffsetBox custom picker)
* :ghpull:`30096`: Fix OffsetBox custom picker
* :ghpull:`30081`: Backport PR #30079 on branch v3.10.x (FIX: cast legend handles to list)
* :ghpull:`30079`: FIX: cast legend handles to list
* :ghpull:`30057`: Backport PR #29895 on branch v3.10.x (The 'lines.markeredgecolor' now doesn't interfere on the color of errorbar caps)"
* :ghpull:`29895`: The 'lines.markeredgecolor' now doesn't interfere on the color of errorbar caps
* :ghpull:`30033`: Backport PR #30029 on branch v3.10.x (Update diagram in subplots_adjust documentation to clarify parameters)

Issues (18):

* :ghissue:`30370`: [Bug]: matplotlib simple example fails in Python 3.14
* :ghissue:`30218`: [Bug]: Rendering on Wayland with fractional scaling looks bad
* :ghissue:`30318`: [Bug]: type annotation of ``Axes.get_legend()`` misses ``None``
* :ghissue:`30169`: [Doc]: Incorrect FAQ Link on Tutorials Page
* :ghissue:`30285`: [Bug]: Missing whitespace in _axes.py error message
* :ghissue:`30280`: [Bug]: Pillow 11.3 raises a deprecation warning when using TkAgg
* :ghissue:`30158`: [Bug]: Stackplot in SubFigure raises when drawing Legend
* :ghissue:`30216`: [Bug]: stem complaining about PyTorch's Tensor
* :ghissue:`30242`: [Bug]: Cannot create empty FancyArrow (expired numpy deprecation)
* :ghissue:`30249`: [Bug]: DeprecationWarning from Pillow 11.3.0 about 'mode' parameter of PIL.Image.fromarray()
* :ghissue:`29688`: [Bug]: "Bad file descriptor" raised repeatedly when plt.pause() interrupted in IPython
* :ghissue:`27305`: [Bug]: Axes.label_outer() does not work when there is a colorbar
* :ghissue:`30179`: [Bug]: Inner border is not rendered correctly when using log-scale and polar projection.
* :ghissue:`29157`: FUTURE BUG: reconsider how we deep-copy path objects
* :ghissue:`30152`: [Bug]: Test pipeline failure on windows
* :ghissue:`30076`: [Bug]:  Layout Managers are confused by complex arrangement of sub-figures and  gridspec's
* :ghissue:`30078`: [Bug]: legend no longer works with itertools.chain
* :ghissue:`29780`: [Bug]: Setting 'lines.markeredgecolor' affects color of errorbar caps.
